kdelibs/kdelibs-4.11.3-klauncher-ti...

13 lines
668 B
Diff

diff -ur kdelibs-4.11.3/kinit/klauncher.cpp kdelibs-4.11.3-klauncher-timeout/kinit/klauncher.cpp
--- kdelibs-4.11.3/kinit/klauncher.cpp 2013-11-01 16:45:56.000000000 +0100
+++ kdelibs-4.11.3-klauncher-timeout/kinit/klauncher.cpp 2013-12-07 03:36:42.000000000 +0100
@@ -314,7 +314,7 @@
// Same thing if kdeinit dies without warning.
fd_set in;
- timeval tm = { 30, 0 }; // 30 seconds timeout, so we're not stuck in case kdeinit dies on us
+ timeval tm = { 60, 0 }; // 60 seconds timeout, so we're not stuck in case kdeinit dies on us
FD_ZERO ( &in );
FD_SET( sock, &in );
select( sock + 1, &in, 0, 0, &tm );